@@ -20,6 +20,7 @@
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #include <linux/tiocl.h>
+#include <stdint.h>
 
 #include "consolation.h"
 
@@ -108,3 +109,51 @@ void scroll(int sc)
     perror("scroll: TIOCLINUX");
   close(fd);
 }
+
+static int goodchar(unsigned char x)
+{
+  return x >= 0x20 && x < 0x7f;
+}
+
+void set_lut(const char *def)
+{
+  int fd;
+  struct {
+    char subcode;
+    char padding[3];
+    uint32_t lut[8];
+  } l = { TIOCL_SELLOADLUT, 0, 0, 0,
+    0x00000000, /* control chars     */
+    0x03FFE000, /* digits and "-./"  */
+    0x87FFFFFE, /* uppercase and '_' */
+    0x07FFFFFE, /* lowercase         */
+    0x00000000,
+    0x00000000,
+    0xFF7FFFFF, /* latin-1 accented letters, not multiplication sign */
+    0xFF7FFFFF  /* latin-1 accented letters, not division sign */
+  }; /* all of Unicode above U+00FF is considered "word" chars, even
+        frames and the likes */
+
+  /* we allow changing only U+0020..U+7E */
+  if (def)
+  {
+    l.lut[1] = l.lut[2] = l.lut[3] = 0;
+    while (*def) {
+      char c = *def++;
+      if (!goodchar(c))
+        continue;
+      if (*def == '-' && goodchar(def[1])) {
+        ++def;
+        for (; c <= *def; ++c)
+          l.lut[c >> 5] |= 1 << (uint32_t)(c & 31);
+        ++def;
+      }
+      else
+        l.lut[c >> 5] |= 1 << (uint32_t)(c & 31);
+    }
+  }
+  fd = open("/dev/tty0",O_RDWR);
+  if(ioctl(fd, TIOCLINUX, &l)<0)
+    perror("set_lut: TIOCLINUX");
+  close(fd);
+}
