@@ -36,6 +36,7 @@
 #include <libevdev/libevdev.h>
 
 #include "shared.h"
+#include "consolation.h"
 #include "config.h"
 
 #define streq(s1, s2) (strcmp((s1), (s2)) == 0)
@@ -65,6 +66,7 @@ enum options {
 	OPT_SCROLL_BUTTON,
 	OPT_SPEED,
 	OPT_PROFILE,
+	OPT_WORD_CHARS,
 	OPT_VERSION
 };
 
@@ -110,7 +112,9 @@ tools_usage()
 	       "is not explicitly specified it is left at each device's default.\n"
 	       "\n"
 	       "Other options:\n"
-	       "--grab .......... Exclusively grab all openend devices\n"
+	       "--word-chars=<string>.... List of characters that make up words.\n"
+	       "                          Ranges (a-z, A-Z, 0-9 etc.) are allowed.\n"
+	       "--grab .......... Exclusively grab all openend devices.\n"
 	       "--verbose ....... Print debugging output.\n"
 	       "--version ....... Print version information.\n"
 	       "--help .......... Print this help.\n",
@@ -145,6 +149,7 @@ tools_init_context(struct tools_context *context)
 	options->seat = "seat0";
 	options->speed = 0.0;
 	options->profile = LIBINPUT_CONFIG_ACCEL_PROFILE_NONE;
+	options->word_chars = NULL;
 }
 
 int
@@ -181,6 +186,7 @@ tools_parse_args(int argc, char **argv, struct tools_context *context)
 			{ "set-scroll-button", 1, 0, OPT_SCROLL_BUTTON },
 			{ "set-profile", 1, 0, OPT_PROFILE },
 			{ "speed", 1, 0, OPT_SPEED },
+			{ "word-chars", 1, 0, OPT_WORD_CHARS },
 			{ 0, 0, 0, 0}
 		};
 
@@ -333,6 +339,13 @@ tools_parse_args(int argc, char **argv, struct tools_context *context)
 				return 1;
 			}
 			break;
+		case OPT_WORD_CHARS:
+			if (!optarg) {
+				tools_usage();
+				return 1;
+			}
+			options->word_chars = optarg;
+			break;
 		default:
 			tools_usage();
 			return 1;
@@ -500,4 +513,5 @@ tools_device_apply_config(struct libinput_device *device,
 			libinput_device_config_accel_set_profile(device,
 								 options->profile);
 	}
+	set_lut(options->word_chars);
 }
